@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2021 Deepin Technology Co., Ltd.
- *
- * Author:     listenerri <listenerri@gmail.com>
- *
- * Maintainer: listenerri <listenerri@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "wirelesssettings.h"
 #include "../sections/genericsection.h"
@@ -48,6 +31,9 @@ void WirelessSettings::initSections()
 {
     GenericSection *genericSection = new GenericSection(m_connSettings);
     genericSection->setConnectionNameEditable(false);
+    if (genericSection->connectionName().isEmpty()) {
+        genericSection->setConnectionNameEditable(true);
+    }
 
     SecretWirelessSection *secretSection = new SecretWirelessSection(
         m_connSettings->setting(Setting::SettingType::WirelessSecurity).staticCast<WirelessSecuritySetting>(),
@@ -59,9 +45,6 @@ void WirelessSettings::initSections()
     DNSSection *dnsSection = new DNSSection(m_connSettings);
 
     WirelessSection *wirelessSection = new WirelessSection(m_connSettings, m_connSettings->setting(Setting::SettingType::Wireless).staticCast<WirelessSetting>(), ConnectionEditPage::devicePath());
-    // we need enable ssid text edit since it is a hidden wifi edit page if ssid is empty
-    if (!wirelessSection->ssid().isEmpty())
-        wirelessSection->setSsidEditable(false);
 
     // 不用解绑，需要监控的控件有限，不会无限增长
     GSettingWatcher::instance()->bind("wirelessAutoConnect", genericSection->autoConnItem());
@@ -71,6 +54,7 @@ void WirelessSettings::initSections()
     GSettingWatcher::instance()->bind("wirelessWlan", wirelessSection);
 
     connect(genericSection, &GenericSection::editClicked, this, &WirelessSettings::anyEditClicked);
+    connect(genericSection, &GenericSection::ssidChanged, wirelessSection, &WirelessSection::setSsid);
     connect(secretSection, &Secret8021xSection::editClicked, this, &WirelessSettings::anyEditClicked);
     connect(ipv4Section, &MultiIpvxSection::editClicked, this, &WirelessSettings::anyEditClicked);
     connect(ipv6Section, &MultiIpvxSection::editClicked, this, &WirelessSettings::anyEditClicked);
@@ -89,8 +73,6 @@ void WirelessSettings::initSections()
     connect(ipv6Section, &MultiIpvxSection::requestFrameAutoHide, this, &WirelessSettings::requestFrameAutoHide);
     connect(dnsSection, &DNSSection::requestFrameAutoHide, this, &WirelessSettings::requestFrameAutoHide);
 
-    connect(wirelessSection, &WirelessSection::ssidChanged, genericSection, &GenericSection::setConnectionName);
-
     m_sectionsLayout->addWidget(genericSection);
     m_sectionsLayout->addWidget(secretSection);
     m_sectionsLayout->addWidget(ipv4Section);
