@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Hotspot</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Wireless Connection %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE Connection %1</translation>
@@ -428,8 +424,8 @@
         <translation>General</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Name</translation>
+        <source>Name (SSID)</source>
+        <translation>Name (SSID)</translation>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>The name already exists</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation>Name (SSID)</translation>
+    </message>
     <message>
         <source>Name</source>
         <translation>Name</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>Not Bind</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Required</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>Device MAC Addr</translation>
