@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Хотспот</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Безжична връзка: %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE Връзка %1</translation>
@@ -428,8 +424,8 @@
         <translation>Общи</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Име</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>Име</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>Не е свързан</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Задължителен </translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>MAC адрес на устройството</translation>
