@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>হটস্পট</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>%1 তারবিহীন সংযোগ</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>%1 PPPoE সংযোগ</translation>
@@ -428,8 +424,8 @@
         <translation>সাধারণ</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>নাম </translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>নাম </translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>আবাদ্ধ নয়</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>আবশ্যক</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>ডিভাইস ম্যাক Addr</translation>
