@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Punt d&apos;accés</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Connexió sense fil %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>Connexió PPPoE %1</translation>
@@ -428,8 +424,8 @@
         <translation>General</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Nom</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>El nom ja existeix.</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>Nom</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>Sense vincle</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Cal</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>Adreça MAC del dispositiu</translation>
