@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Přípojný bod</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Bezdrátové připojení %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE připojení %1</translation>
@@ -428,8 +424,8 @@
         <translation>Obecné</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Název</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>Název už existuje</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>Název</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>Nespojeno</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Vyžadováno</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>MAC adresa zařízení</translation>
