@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Punto de acceso</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Conexión inalámbrica %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>Conexión PPPoE %1</translation>
@@ -428,8 +424,8 @@
         <translation>General</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Nombre</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>El nombre ya existe</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>Nombre</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>Sin enlazar</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Requerido</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>Dirección MAC del dispositivo</translation>
