@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>هات اسپات</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>اتصال بی سیم %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>اتصال  PPPoE %1</translation>
@@ -428,8 +424,8 @@
         <translation>کلی</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>نام</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>این نام از قبل وجود دارد</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>نام</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>وصل نشد</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>مورد نیاز</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>آدرس MAC دستگاه</translation>
