@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Tukiasema</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Langaton %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE yhteys %1</translation>
@@ -428,8 +424,8 @@
         <translation>Yleinen</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Nimi</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>Nimi on jo olemassa</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>Nimi</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>Ei sido</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Vaadittu</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>MAC-osoite</translation>
