@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Point d&apos;accès</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Connexion sans fil %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>Connexion PPPoE %1</translation>
@@ -428,8 +424,8 @@
         <translation>Général</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Nom</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>Le nom existe déjà</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>Nom</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>Ne pas lier</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Obligatoire</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>Adresse MAC du périphérique</translation>
