@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>हॉटस्पॉट</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Wireless Connection %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE Connection %1</translation>
@@ -428,8 +424,8 @@
         <translation>सामान्य</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>नाम</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>नाम</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>आवश्यक</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>उपकरण MAC ऐड्रेस</translation>
