@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Hotspot</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Connessione WiFi %1 </translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>Connessione PPPoE %1</translation>
@@ -428,8 +424,8 @@
         <translation>Generale</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Nome</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>Questo nome esiste già</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>Nome</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>Non collegato</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Richiesta</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>Indirizzo MAC</translation>
