@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>ホットスポット</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>無線接続 %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE 接続 %1</translation>
@@ -428,8 +424,8 @@
         <translation>一般</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>名前</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>この名前はすでに存在します</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>名前</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>バインドされていません</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>必須</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>デバイスの MAC アドレス</translation>
