@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>핫스팟</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>무선 연결 %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE 연결 %1</translation>
@@ -428,8 +424,8 @@
         <translation>일반</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>이름</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>이름이 이미 존재합니다</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>이름</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>바인딩 안함</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>필수 항목</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>장치 MAC 주소</translation>
