@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Prieigos taškas</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Belaidis ryšys %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE ryšys %1</translation>
@@ -428,8 +424,8 @@
         <translation>Bendra</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Pavadinimas</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>Pavadinimas jau yra</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>Pavadinimas</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>Nesusietas</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Būtina</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>Įrenginio MAC adresas</translation>
