@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Утасгүй сүлжээ цацагч</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Утасгүй холболт %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE холболт %1</translation>
@@ -428,8 +424,8 @@
         <translation>Ерөнхий</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Нэр</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>Нэр</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>Бэхлэгдээгүй</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Шаардлагатай</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>Төхөөрөмжийн МАК хаяг</translation>
