@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Hotspot</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Trådløs Forbindelse %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE Forbindelse %1</translation>
@@ -429,8 +425,8 @@
         <translation>Generel</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Navn</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -447,6 +443,10 @@
         <source>The name already exists</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>Navn</translation>
@@ -1930,14 +1930,6 @@
         <source>Not Bind</source>
         <translation>Ikke Bind</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Påkrevd</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>Enhet MAC adr</translation>
