@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Hotspot</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Draadloze verbinding %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE-verbinding %1</translation>
@@ -428,8 +424,8 @@
         <translation>Algemeen</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Naam</translation>
+        <source>Name (SSID)</source>
+        <translation>Naam (SSID)</translation>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>Deze naam is al in gebruik</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation>Naam (SSID)</translation>
+    </message>
     <message>
         <source>Name</source>
         <translation>Naam</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>Niet verbonden</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Vereist</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>MAC-adres van apparaat</translation>
