@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Hotspot</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Połączenie bezprzewodowe %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>Połączenie PPPoE %1</translation>
@@ -428,8 +424,8 @@
         <translation>Ogólne</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Nazwa</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>Taka nazwa już istnieje</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>Nazwa</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>Nie znaleziono</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Wymagane</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>Adres MAC urządzenia</translation>
