@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>හොට්ස්පොට්</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>රැහැන් රහිත සම්බන්ධතාවය: %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE සම්බන්ධතාවය %1</translation>
@@ -428,8 +424,8 @@
         <translation>පොදු</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>නම</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>නම දැනටමත් පවතී</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>නම</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>බැඳී නොමැත</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>අත්‍යවශ්‍යයි</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>උපාංගයේ MAC ලිපිනය</translation>
