@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Dostopna točka</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Brezžična povezava %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE povezava %1</translation>
@@ -428,8 +424,8 @@
         <translation>Splošno</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Ime</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>To ime že obstaja</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>Ime</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>Brez vezave</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Obvezno</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>MAC naslov naprave</translation>
