@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Hotspot</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Lidhje Pa Fill %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>Lidhje PPPoE %1</translation>
@@ -428,8 +424,8 @@
         <translation>Të përgjithshme</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Emër</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>Emri ekziston tashmë</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>Emër</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>E domosdoshme</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>Adresë Mac Pajisjeje</translation>
