@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>Точка доступу</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>Бездротове з&apos;єднання %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>З&apos;єднання PPPoE %1</translation>
@@ -428,8 +424,8 @@
         <translation>Загальне</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>Назва</translation>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>Таке ім&apos;я вже існує</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Name</source>
         <translation>Назва</translation>
@@ -844,19 +844,19 @@
     </message>
     <message>
         <source>Authentication is required</source>
-        <translation type="unfinished"/>
+        <translation>Слід пройти розпізнавання</translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"/>
+        <translation>Користувач</translation>
     </message>
     <message>
         <source>Required</source>
-        <translation type="unfinished"/>
+        <translation>Обов&apos;язкове</translation>
     </message>
     <message>
         <source>Password</source>
-        <translation type="unfinished"/>
+        <translation>Пароль</translation>
     </message>
     <message>
         <source>HTTP Proxy</source>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>Не прив&apos;язано</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Потрібен</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>Пристрій MAC Addr</translation>
