@@ -98,10 +98,6 @@
         <source>Hotspot</source>
         <translation>無線熱點</translation>
     </message>
-    <message>
-        <source>Wireless Connection %1</source>
-        <translation>無線網路 %1</translation>
-    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE 連線 %1</translation>
@@ -428,8 +424,8 @@
         <translation>一般</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation>名稱</translation>
+        <source>Name (SSID)</source>
+        <translation>名稱（SSID）</translation>
     </message>
     <message>
         <source>Required</source>
@@ -446,6 +442,10 @@
         <source>The name already exists</source>
         <translation>名稱已存在</translation>
     </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation>名稱（SSID）</translation>
+    </message>
     <message>
         <source>Name</source>
         <translation>名稱</translation>
@@ -1929,14 +1929,6 @@
         <source>Not Bind</source>
         <translation>未連結</translation>
     </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>必填</translation>
-    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>裝置 MAC 位址</translation>
