@@ -1,4 +1,15 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
+<context>
+    <name>DeviceControllItem</name>
+    <message>
+        <source>Wireless Network</source>
+        <translation>Réseau sans fil</translation>
+    </message>
+    <message>
+        <source>Wired Network</source>
+        <translation>Réseau filaire</translation>
+    </message>
+</context>
 <context>
     <name>NetworkPlugin</name>
     <message>
@@ -6,6 +17,31 @@
         <translation>Réseau</translation>
     </message>
 </context>
+<context>
+    <name>WirelessItem</name>
+    <message>
+        <source>Connect to hidden network</source>
+        <translation>Se connecter à un réseau caché</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Mot de passe</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation>Annuler</translation>
+    </message>
+    <message>
+        <source>Connect</source>
+        <comment>button</comment>
+        <translation>Relier</translation>
+    </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation>Nom (SSID)</translation>
+    </message>
+</context>
 <context>
     <name>dde::network::NetworkDetails</name>
     <message>
@@ -24,14 +60,14 @@
         <source>Security Type</source>
         <translation>Type de sécurité</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Bande</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Canal</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Bande</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Interface</translation>
