@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
 <context>
     <name>Bubble</name>
     <message>
@@ -6,6 +6,17 @@
         <translation>1 nouveau message</translation>
     </message>
 </context>
+<context>
+    <name>DeviceControllItem</name>
+    <message>
+        <source>Wireless Network</source>
+        <translation>Réseau sans fil</translation>
+    </message>
+    <message>
+        <source>Wired Network</source>
+        <translation>Réseau filaire</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -42,10 +53,28 @@
     </message>
 </context>
 <context>
-    <name>dss::module::NetworkModule</name>
+    <name>WirelessItem</name>
     <message>
-        <source>Wired Connection</source>
-        <translation>Connexion filaire</translation>
+        <source>Connect to hidden network</source>
+        <translation>Se connecter à un réseau caché</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Mot de passe</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation>Annuler</translation>
+    </message>
+    <message>
+        <source>Connect</source>
+        <comment>button</comment>
+        <translation>Relier</translation>
+    </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation>Nom (SSID)</translation>
     </message>
 </context>
 <context>
@@ -66,14 +95,14 @@
         <source>Security Type</source>
         <translation>Type de sécurité</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Bande</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Canal</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Bande</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Interface</translation>
@@ -240,4 +269,11 @@
         <translation>Paramètres réseau</translation>
     </message>
 </context>
+<context>
+    <name>dss::module::NetworkModule</name>
+    <message>
+        <source>Wired Connection</source>
+        <translation>Connexion filaire</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
