@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
 <context>
     <name>Bubble</name>
     <message>
@@ -6,6 +6,17 @@
         <translation>Одно новое сообщение</translation>
     </message>
 </context>
+<context>
+    <name>DeviceControllItem</name>
+    <message>
+        <source>Wireless Network</source>
+        <translation>Беспроводная сеть</translation>
+    </message>
+    <message>
+        <source>Wired Network</source>
+        <translation>Проводная сеть</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -42,10 +53,28 @@
     </message>
 </context>
 <context>
-    <name>dss::module::NetworkModule</name>
+    <name>WirelessItem</name>
     <message>
-        <source>Wired Connection</source>
-        <translation>Проводное Соединение</translation>
+        <source>Connect to hidden network</source>
+        <translation>Подключиться к скрытой сети</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Пароль</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation>Отмена</translation>
+    </message>
+    <message>
+        <source>Connect</source>
+        <comment>button</comment>
+        <translation>Подключить</translation>
+    </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation>Имя (SSID)</translation>
     </message>
 </context>
 <context>
@@ -66,14 +95,14 @@
         <source>Security Type</source>
         <translation>Тип безопасности</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Диапазон</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Канал</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Диапазон</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Интерфейс</translation>
@@ -240,4 +269,11 @@
         <translation>Настройки сети</translation>
     </message>
 </context>
+<context>
+    <name>dss::module::NetworkModule</name>
+    <message>
+        <source>Wired Connection</source>
+        <translation>Проводное Соединение</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
